@@ -26,6 +26,8 @@
 						- Joe M. Wade 03/15/96 
 */
 #include <stdio.h>
+#include <stdlib.h>
+#include <time.h>
 #include <unistd.h>
 #include <localsys.h>
 #include <size_defs.h>
@@ -847,7 +849,7 @@ void read_err()
 	fflush(fdout);
 	fclose(fdout);
 	fclose(prtfile);
-	abort(100);
+	abort();
 	exit(0);
 }
 
@@ -859,7 +861,7 @@ void write_err()
 	  "ERROR: qdslice - error writing output data\n");
 	fclose(fdout);
 	fclose(prtfile);
-	abort(100);
+	abort();
 	exit(0);
 }
 int get_full_word(source)
