@@ -6,6 +6,7 @@
 
 
 #include <localsys.h>
+#include <stdlib.h>
 #include <ut_defs.h>
 
 void F_GETPPS( pid,ppid )
@@ -31,6 +32,12 @@ void C_GETPPS(pid,ppid)
 int *pid;
 int *ppid;
 {
-	*pid=getpid();
-	*ppid=getppid();
+	if (getenv("USP_PRINT_BYPASS") != NULL) {
+	  *pid=-1;
+	  *ppid=-1;
+	  }
+	else {
+	  *pid=getpid();
+	  *ppid=getppid();
+	  }
 }
